==> rewrite-servlet-2.0.12.Final-sources.jar: org/ocpsoft/rewrite/servlet/impl/Servlet25DispatcherTypeProvider.java <==
/*
 * Copyright 2011 <a href="mailto:lincolnbaxter@gmail.com">Lincoln Baxter, III</a>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ocpsoft.rewrite.servlet.impl;

import javax.servlet.ServletContext;
import javax.servlet.ServletRequest;

import org.ocpsoft.rewrite.servlet.DispatcherType;
import org.ocpsoft.rewrite.servlet.spi.DispatcherTypeProvider;

/**
 * Implementation of {@link DispatcherTypeProvider} for Servlet 2.5 which uses special request attributes to detect the
 * dispatcher type.
 * 
 * @author Christian Kaltepoth
 */
public class Servlet25DispatcherTypeProvider implements DispatcherTypeProvider
{

   @Override
   public int priority()
   {
      return 20;
   }

   @Override
   public DispatcherType getDispatcherType(ServletRequest request, ServletContext context)
   {
      if (request.getAttribute("javax.servlet.forward.request_uri") != null) {
         return DispatcherType.FORWARD;
      }
      if (request.getAttribute("javax.servlet.include.request_uri") != null) {
         return DispatcherType.INCLUDE;
      }
      return DispatcherType.REQUEST;

   }

}

==> rewrite-servlet-3.5.1.Final-sources.jar: org/ocpsoft/rewrite/servlet/impl/Servlet25DispatcherTypeProvider.java <==
/*
 * Copyright 2011 <a href="mailto:lincolnbaxter@gmail.com">Lincoln Baxter, III</a>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ocpsoft.rewrite.servlet.impl;

import javax.servlet.ServletContext;
import javax.servlet.ServletRequest;

import org.ocpsoft.rewrite.servlet.DispatcherType;
import org.ocpsoft.rewrite.servlet.spi.DispatcherTypeProvider;

/**
 * Implementation of {@link DispatcherTypeProvider} for Servlet 2.5 which uses special request attributes to detect the
 * dispatcher type.
 * 
 * @author Christian Kaltepoth
 */
public class Servlet25DispatcherTypeProvider implements DispatcherTypeProvider
{

   @Override
   public int priority()
   {
      return 20;
   }

   @Override
   public DispatcherType getDispatcherType(ServletRequest request, ServletContext context)
   {
      if (request.getAttribute("javax.servlet.forward.request_uri") != null) {
         return DispatcherType.FORWARD;
      }

      if (request.getAttribute("javax.servlet.include.request_uri") != null) {
         return DispatcherType.INCLUDE;
      }

      Throwable throwable = (Throwable) request.getAttribute("javax.servlet.error.exception");
      if (throwable != null) {
         return DispatcherType.ERROR;
      }

      return DispatcherType.REQUEST;
   }

}
